@@ -60,7 +60,7 @@ SqlrefpolicyCleanup::SqlrefpolicyCleanup(QFile)
          		QString av_str;
 			int av_int;
 			while ( !stream.atEnd() ) {
-				line_analized = stream.readLine(); // line of text excluding '\n'
+				line_analized = stream.readLine(); // line of text excluding 'n'
 				if(line_analized.contains(",", Qt::CaseInsensitive)){
 					//list2 = line_analized.split(" ");
 					list2 = line_analized.split(",", QString::SkipEmptyParts);	
@@ -86,19 +86,19 @@ SqlrefpolicyCleanup::SqlrefpolicyCleanup(QFile)
 						}
 					}
 					//lines += log_str_scontext + "," + log_str_tcontext + "," + log_str_tclass + "," + log_str_access_vector;
-					lines += "Alert!! <font color=\"purple\">" + log_str_scontext + " </font> wants to <font color=\"red\"> " + log_str_access_vector + "  </font><font color=\"blue\"> " + log_str_tclass + " </font> in <font color=\"green\">" + log_str_tcontext + " </font> Refpolicy Analyzer will help you. <br />";
+					lines += "Alert!! <font color="purple">" + log_str_scontext + " </font> wants to <font color="red"> " + log_str_access_vector + "  </font><font color="blue"> " + log_str_tclass + " </font> in <font color="green">" + log_str_tcontext + " </font> Refpolicy Analyzer will help you. <br />";
 
 				}
 			}
 			//lines.removeDuplicates();
 			//lines.sort();
-			lines += "Alert!! <font color=\"purple\">" + log_str_scontext + " </font> wants to <font color=\"red\"> " + log_str_access_vector + "  </font><font color=\"blue\"> " + log_str_tclass + " </font> in <font color=\"green\">" + log_str_tcontext + " </font> Refpolicy Analyzer will help you. <br />";
+			lines += "Alert!! <font color="purple">" + log_str_scontext + " </font> wants to <font color="red"> " + log_str_access_vector + "  </font><font color="blue"> " + log_str_tclass + " </font> in <font color="green">" + log_str_tcontext + " </font> Refpolicy Analyzer will help you. <br />";
 		}
 		file.close();
 		++it_d;
 	}
 	*/
-	//lines += "Alert!! <font color=\"purple\">" + log_str_scontext + " </font> wants to <font color=\"red\"> " + log_str_access_vector + "  </font><font color=\"blue\"> " + log_str_tclass + " </font> in <font color=\"green\">" + log_str_tcontext + " </font> Refpolicy Analyzer will help you. <br />";
+	//lines += "Alert!! <font color="purple">" + log_str_scontext + " </font> wants to <font color="red"> " + log_str_access_vector + "  </font><font color="blue"> " + log_str_tclass + " </font> in <font color="green">" + log_str_tcontext + " </font> Refpolicy Analyzer will help you. <br />";
 	
 	lines += "Alert!!";
 	//writing to file
