@@ -44,7 +44,6 @@ class Aureport: public QDialog
 	Q_OBJECT
 public:
 	Aureport(QWidget *parent = 0, const char *name = 0);
-	AureportProcess *aureport_process;
 public slots:
 signals:
 protected:
@@ -108,6 +107,7 @@ private:
         QString starttimeEditLineEdit_str;
         QString enddayEditLineEdit_str;
         QString endtimeEditLineEdit_str;
+        AureportProcess *aureport_process_o;
 
 };
 
