@@ -37,7 +37,8 @@ using namespace std;
 //default constructor
 Ausearch::Ausearch(QWidget *parent, const char *name): QDialog(parent, name)
 {
-	//setCaption(tr("Ausearch"));
+	ausearch_process_o = 0;
+
 	ausearchLabel = new QLabel(tr("Search about"),this);
 	startdayLabel = new QLabel(tr("start-day ex.(1/1/2014)"),this);
 	starttimeLabel = new QLabel(tr("start-time"),this);
@@ -106,7 +107,7 @@ Ausearch::Ausearch(QWidget *parent, const char *name): QDialog(parent, name)
 	setLayout(mainLayout);
 	setWindowTitle(tr("Ausearch"));
 
-	ausearch_process = 0;
+	ausearch_process_o = 0;
 }
 
 QGroupBox *Ausearch::createFirstExclusiveGroup()
@@ -227,13 +228,12 @@ void Ausearch::ausearch_button_clicked()
 		ausearch_str_pp_str = ausearch_str_pp_str + " --end " + enddayEditLineEdit_str + " " + endtimeEditLineEdit_str;
 	}
 
-	ausearch_process = new AusearchProcess(this);
-	connect(closeButton, SIGNAL(clicked()), ausearch_process, SLOT(close()));
-	ausearch_process->setCaption(tr(ausearch_str_pp_str));
-	ausearch_process->show();
-	ausearch_process->raise();
-	ausearch_process->setActiveWindow();
+	ausearch_process_o = new AusearchProcess(ausearch_str_pp_str,this);
+	connect(closeButton, SIGNAL(clicked()), ausearch_process_o, SLOT(close()));
 
-	ausearch_process->ausearch_base_process(ausearch_str_pp_str);
+	ausearch_process_o->setCaption(tr(ausearch_str_pp_str));
+	ausearch_process_o->show();
+	ausearch_process_o->raise();
+	ausearch_process_o->setActiveWindow();
 
 }
