@@ -112,5 +112,5 @@ void BreakTe::breakte_base_process()
 	connect(process, SIGNAL(readyReadStandardOutput()),this,SLOT(readFromStdout()));
 	connect(process, SIGNAL(readyReadStandardError()),this,SLOT(updateOutputTextEdit()));
 	connect(process, SIGNAL(finished(int, QProcess::ExitStatus)),this,SLOT(processExited(int, QProcess::ExitStatus)));
-	process->start("/usr/share/segatex/raw_te_files/breakte.sh");
+	process->start("/bin/bash", QStringList() << "-c" << "export LANG=C;/usr/share/segatex/raw_te_files/breakte.sh");
 }
