@@ -18,17 +18,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <q3textedit.h>
-#include <q3process.h>
-#include <qmessagebox.h>
-//Added by qt3to4:
+#include <QLayout>
+#include <QLineEdit>
+#include <QPushButton>
+#include <QRadioButton>
+#include <QTextEdit>
+#include <QMessageBox>
 #include <Q3TextStream>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
 #include <QLabel>
 //#include <fstream.h>
 #include <fstream>
@@ -42,7 +38,7 @@ using namespace std;
 Seeprocess::Seeprocess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("see process"));
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(174,187,255));
 	grepLabel = new QLabel(tr("grep:"), this );
 	grepEditLineEdit = new QLineEdit(this );
@@ -64,12 +60,12 @@ Seeprocess::Seeprocess(QWidget *parent, const char *name): QDialog(parent, name)
 	//connect(seeprocessEndButton, SIGNAL(clicked()), this, SLOT(seeprocess_end_clicked()));
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 
-	firstLayout = new Q3VBoxLayout;
-	leftLayout = new Q3HBoxLayout;
+	firstLayout = new QVBoxLayout;
+	leftLayout = new QHBoxLayout;
 	leftLayout->addWidget(grepLabel);
 	leftLayout->addWidget(grepEditLineEdit);
 
-	rightLayout = new Q3VBoxLayout;
+	rightLayout = new QVBoxLayout;
 	rightLayout->addWidget(grepButton);
 	rightLayout->addStretch(1);
 	rightLayout->addWidget(seeprocessButton);
@@ -79,7 +75,7 @@ Seeprocess::Seeprocess(QWidget *parent, const char *name): QDialog(parent, name)
 	firstLayout->addLayout(leftLayout);
 	firstLayout->addWidget(textEdit1);
 
-	mainLayout = new Q3HBoxLayout(this);
+	mainLayout = new QHBoxLayout(this);
 	mainLayout->setMargin(11);
 	mainLayout->setSpacing(6);
 	mainLayout->addLayout(firstLayout);
@@ -111,13 +107,13 @@ void Seeprocess::grep_clicked()
 ////////////////////////////////////////////
 void Seeprocess::readFromStdout()
 {
-        QByteArray data = process->readStdout();
+        QByteArray data = process->readAllStandardOutput();
         QString text = textEdit1->text() + QString(data);
         textEdit1->setText(text);
 }
 void Seeprocess::processExited()
 {
-	if(process->normalExit()){
+	if(process->exitStatus()==0){
 		//textEdit1->append(tr(""));
 		//textEdit1->append(tr("\n"));
 	} else {
@@ -186,23 +182,20 @@ void Seeprocess::seeprocess_grep_process(QString grep_str)
 void Seeprocess::seeprocess_base_process()
 {
 	this->setEnabled(false);
-	process = new Q3Process(this);
-	process->addArgument("/usr/share/segatex/SILENCE_SETROUBLESHOOTD_FOR_SEEPROCESS");
+	process = new QProcess(this);
 	connect(process, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout()));
 	connect(process, SIGNAL(readyReadStderr()),this,SLOT(updateOutputTextEdit()));
 	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
-	//process->addArgument("/usr/share/segatex/SILENCE_SETROUBLESHOOTD_FOR_SEEPROCESS_END");
-	process->start();
+	process->start("/usr/share/segatex/SILENCE_SETROUBLESHOOTD_FOR_SEEPROCESS");
 }
 void Seeprocess::seeprocess_end()
 {
 	this->setEnabled(false);
-	process_end = new Q3Process(this);
-	process_end->addArgument("/usr/share/segatex/SILENCE_SETROUBLESHOOTD_FOR_SEEPROCESS_END");
+	process_end = new QProcess(this);
 	connect(process_end, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout()));
 	connect(process_end, SIGNAL(readyReadStderr()),this,SLOT(updateOutputTextEdit()));
 	connect(process_end, SIGNAL(processExited()),this,SLOT(processExited()));
-	process_end->start();
+	process_end->start("/usr/share/segatex/SILENCE_SETROUBLESHOOTD_FOR_SEEPROCESS_END");
 }
 //this slot should be called from above slot
 void Seeprocess::readFromOutputFile()
@@ -238,7 +231,7 @@ void Seeprocess::readFromOutputFile()
 				//do nothing
 			}
 		}
-		textEdit1->setCursorPosition(0,0);
+		//textEdit1->setCursorPosition(0,0);
 }
 //this slot should be called from above slot
 void Seeprocess::readFromOutputFile_grep(QString grep_str)
@@ -279,7 +272,7 @@ void Seeprocess::readFromOutputFile_grep(QString grep_str)
 						//do nothing
 					}
 				}
-				textEdit1->setCursorPosition(0,0);
+				//textEdit1->setCursorPosition(0,0);
 				file.close();
 				++it_d;
 			}else{
