@@ -20,18 +20,19 @@
 #ifndef SEGATEXCORE_H
 #define SEGATEXCORE_H
 
-#include <qregexp.h>
-#include <qdialog.h>
-#include <qradiobutton.h>
-#include <q3textedit.h>
+#include <QRegExp>
+#include <QDialog>
+#include <QRadioButton>
+#include <QTextEdit>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 
 
 class QLayout;
 class QCheckBox;
-class Q3TextEdit;
+class QTextEdit;
 class QLineEdit;
 class QPushButton;
-class Q3Process;
 class SegatexCoreProcess;
 class SegatexCore2Process;
 
@@ -54,6 +55,10 @@ private:
         QPushButton *closeButton;
         SegatexCoreProcess *segatex_core_process;
         SegatexCore2Process *segatex_core2_process;
+        QVBoxLayout *leftLayout;
+        QVBoxLayout *rightLayout;
+        QVBoxLayout *mainLayout;
+        QHBoxLayout *footLayout;
 };
 
 #endif
