@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <Q3TextStream>
-#include <qmessagebox.h>
+#include <QTextStream>
+#include <QMessageBox>
 //########by me#######
 #include <sepol/sepol.h>
 #include <unistd.h>
@@ -39,16 +39,16 @@ using namespace std;
 SegatexGetpidcon::SegatexGetpidcon(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Getpidcon"));
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
 	closeButton = new QPushButton(tr("close"), this);
 	//closing process button
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 	closeButton->setDefault(true);
-	mainLayout = new Q3VBoxLayout(this);
+	mainLayout = new QVBoxLayout(this);
 	mainLayout->setMargin(11);
 	mainLayout->addWidget(textEdit1);
-	footLayout = new Q3HBoxLayout(this);
+	footLayout = new QHBoxLayout(this);
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 	mainLayout->addLayout(footLayout);
@@ -145,7 +145,7 @@ void SegatexGetpidcon::readFromOutputFile()
 			//cout << "file_interface_name:" << file_interface_name << endl;
 			QFile file( file_interface_name );
 			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
+				QTextStream stream( &file );
 				////////////////////////////////////////////
 				while ( !stream.atEnd() ) {
 					line_analized = stream.readLine(); // line of text excluding '\n'
@@ -158,5 +158,5 @@ void SegatexGetpidcon::readFromOutputFile()
 				//do nothing
 			}
 		}
-	textEdit1->setCursorPosition(0,0);
+	//textEdit1->setCursorPosition(0,0);
 }
