@@ -21,13 +21,13 @@
 #ifndef SEGATEXGETSEUSERBYNAME_H
 #define SEGATEXGETSEUSERBYNAME_H
 
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qlabel.h> 
+#include <QDialog>
+#include <QLayout>
+#include <QLabel> 
 #include <QLineEdit> 
-#include <q3textedit.h>
-//Added by qt3to4:
-#include <Q3HBoxLayout>
+#include <QTextEdit>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 
 #include <selinux/selinux.h>
 
@@ -48,9 +48,9 @@ private:
 	QPushButton *getButton;
 	QPushButton *closeButton;
 
-	Q3VBoxLayout *mainLayout;
-	Q3HBoxLayout *leftLayout;
-	Q3HBoxLayout *rightLayout;
+	QVBoxLayout *mainLayout;
+	QHBoxLayout *leftLayout;
+	QHBoxLayout *rightLayout;
 
         QLabel *getseuserbynameLabel;
         QLabel *getseuserbynameLabel2;
