@@ -21,9 +21,9 @@
 #ifndef SEGATEXGETSEUSERBYNAMEPROCESS_H
 #define SEGATEXGETSEUSERBYNAMEPROCESS_H
 
-#include <qregexp.h>
+#include <QRegExp>
 #include <QPushButton>
-#include <q3textedit.h>
+#include <QTextEdit>
 
 #include <selinux/selinux.h>
 #include "segatex_getseuserbyname.h"
@@ -42,7 +42,7 @@ signals:
 protected:
 private slots:
 private:
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 	QPushButton *closeButton;
 	QString linuxuser_str;
 	QString seuser_str;
