@@ -21,15 +21,15 @@
 #ifndef SEGATEXSETENFORCE_H
 #define SEGATEXSETENFORCE_H
 
-#include <q3textedit.h>
+#include <QTextEdit>
 
 #include <selinux/selinux.h>
 #include <selinux/get_default_type.h>
 
-class Q3TextEdit;
+class QTextEdit;
 class MainWindow;
 
-class SegatexSetenforce: public Q3TextEdit
+class SegatexSetenforce: public QTextEdit
 {
 	Q_OBJECT
 public:
