@@ -18,17 +18,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <q3process.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-#include <qregexp.h>
-//Added by qt3to4:
-#include <Q3TextStream>
-#include <Q3HBoxLayout>
+#include <QLayout>
+#include <QPushButton>
+#include <QProcess>
+#include <QLineEdit>
+#include <QTextEdit>
+#include <QRegExp>
+#include <QTextStream>
 #include <QLabel>
-#include <Q3VBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -45,7 +42,7 @@ using namespace std;
 SemanageCoreFcontextProcess::SemanageCoreFcontextProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Semanage Fcontext Process"));
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
 
 	semanageEditLabel = new QLabel(tr("fcontext:"), this );
@@ -124,17 +121,17 @@ SemanageCoreFcontextProcess::SemanageCoreFcontextProcess(QWidget *parent, const
 	//set textEdit smanage such and such -l
 	semanage_core_base_fcontext_process();
 
-	mainLayout = new Q3VBoxLayout(this);
+	mainLayout = new QVBoxLayout(this);
 	mainLayout->setMargin(15);
 
-	upperLayout = new Q3VBoxLayout;
+	upperLayout = new QVBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	middleLayout = new Q3VBoxLayout;
-	leftLayout = new Q3HBoxLayout;
-	rightLayout = new Q3HBoxLayout;
-	thirdLayout = new Q3HBoxLayout;
-	fourthLayout = new Q3HBoxLayout;
+	middleLayout = new QVBoxLayout;
+	leftLayout = new QHBoxLayout;
+	rightLayout = new QHBoxLayout;
+	thirdLayout = new QHBoxLayout;
+	fourthLayout = new QHBoxLayout;
 	
 	leftLayout->addWidget(semanageEditLabel);
 	leftLayout->addWidget(semanageEditLineEdit);
@@ -164,7 +161,7 @@ SemanageCoreFcontextProcess::SemanageCoreFcontextProcess(QWidget *parent, const
 	middleLayout->addLayout(thirdLayout);
 	middleLayout->addLayout(fourthLayout);
 
-	footLayout = new Q3HBoxLayout;
+	footLayout = new QHBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -644,7 +641,7 @@ void SemanageCoreFcontextProcess::readFromOutputFile()
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
 			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
+				QTextStream stream( &file );
 				////////////////////////////////////////////
 				//int i,j,k,l,m,n;	
 				if(order_x == 1)
@@ -654,7 +651,7 @@ void SemanageCoreFcontextProcess::readFromOutputFile()
 					line_analized = stream.readLine(); // line of text excluding '\n'
 					textEdit1->append(line_analized);
 				}
-				textEdit1->setCursorPosition(0,0);
+				//textEdit1->setCursorPosition(0,0);
 				file.close();
 				order_x++;
 				++it_d;
