@@ -21,18 +21,16 @@
 #ifndef SEMANAGECOREFCONTEXTPROCESS_H
 #define SEMANAGECOREFCONTEXTPROCESS_H
 
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qdir.h> 
-#include <qregexp.h> 
-#include <qlabel.h> 
-#include <q3textedit.h>
-#include <q3buttongroup.h>
-#include <qradiobutton.h>
-//Added by qt3to4:
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
-
+#include <QDialog>
+#include <QLayout>
+#include <QDir> 
+#include <QRegExp> 
+#include <QLabel> 
+#include <QTextEdit>
+#include <Q3ButtonGroup>
+#include <QRadioButton>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 
 class QLayout;
 class QLineEdit;
@@ -62,7 +60,7 @@ private:
 	QPushButton *deleteButton;
 	QPushButton *modifyButton;
 	QPushButton *closeButton;
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 	QRadioButton *allfilesRadioButton;
 	QRadioButton *regularfileRadioButton;
 	QRadioButton *directoryRadioButton;
@@ -72,15 +70,15 @@ private:
 	QRadioButton *symboliclinkRadioButton;
 	QRadioButton *namedpipeRadioButton;
 
-	Q3VBoxLayout *mainLayout;
-	Q3VBoxLayout *upperLayout;
-	Q3VBoxLayout *underLayout;
-	Q3HBoxLayout *leftLayout;
-	Q3HBoxLayout *rightLayout;
-	Q3HBoxLayout *thirdLayout;
-	Q3HBoxLayout *fourthLayout;
-	Q3VBoxLayout *middleLayout;
-	Q3HBoxLayout *footLayout;
+	QVBoxLayout *mainLayout;
+	QVBoxLayout *upperLayout;
+	QVBoxLayout *underLayout;
+	QHBoxLayout *leftLayout;
+	QHBoxLayout *rightLayout;
+	QHBoxLayout *thirdLayout;
+	QHBoxLayout *fourthLayout;
+	QVBoxLayout *middleLayout;
+	QHBoxLayout *footLayout;
 
         QDir dir;
         QString path;
