@@ -21,19 +21,17 @@
 #ifndef SEMANAGECOREPORTPROCESS_H
 #define SEMANAGECOREPORTPROCESS_H
 
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qdir.h> 
-#include <qregexp.h> 
-#include <qlabel.h> 
-#include <q3textedit.h>
-//Added by qt3to4:
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
-
+#include <QDialog>
+#include <QLayout>
+#include <QDir>
+#include <QRegExp> 
+#include <QLabel> 
+#include <QTextEdit>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 
 class QLayout;
-class Q3TextEdit;
+class QTextEdit;
 class QLineEdit;
 class QPushButton;
 
@@ -60,16 +58,16 @@ private:
 	QPushButton *deleteButton;
 	QPushButton *modifyButton;
 	QPushButton *closeButton;
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 
-	Q3VBoxLayout *mainLayout;
-	Q3VBoxLayout *upperLayout;
-	Q3VBoxLayout *underLayout;
-	Q3HBoxLayout *leftLayout;
-	Q3HBoxLayout *rightLayout;
-	Q3HBoxLayout *thirdLayout;
-	Q3VBoxLayout *middleLayout;
-	Q3HBoxLayout *footLayout;
+	QVBoxLayout *mainLayout;
+	QVBoxLayout *upperLayout;
+	QVBoxLayout *underLayout;
+	QHBoxLayout *leftLayout;
+	QHBoxLayout *rightLayout;
+	QHBoxLayout *thirdLayout;
+	QVBoxLayout *middleLayout;
+	QHBoxLayout *footLayout;
 
         QDir dir;
         QString path;
