@@ -18,16 +18,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <q3textedit.h>
-#include <qlayout.h>
-#include <qradiobutton.h>
-#include <qmessagebox.h>
-#include <qpushbutton.h>
-#include <q3buttongroup.h>
-#include <q3textedit.h>
-#include <Q3VBoxLayout>
-#include <Q3HBoxLayout>
-#include <Q3TextStream>
+#include <QTextEdit>
+#include <QLayout>
+#include <QRadioButton>
+#include <QMessageBox>
+#include <QPushButton>
+#include <QButtonGroup>
+#include <QTextEdit>
+#include <QTextStream>
 
 #include "semodule_dontaudit.h"
 #include "semodule_dontaudit_process.h"
@@ -94,13 +92,13 @@ void SemoduleDontaudit::dontaudit_clicked()
 ////////////////////////////////////////////
 void SemoduleDontaudit::readFromStdout()
 {
-        QByteArray data = process->readStdout();
+        QByteArray data = process->readAllStandardOutput();
         QString text = textEdit1->text() + QString(data);
         textEdit1->setText(text);
 }
 void SemoduleDontaudit::processExited()
 {
-	if(process->normalExit()){
+	if(process->exitStatus()==0){
 		
 		//for test to echo rightly
 		semodule_dontaudit_base_process();
@@ -118,12 +116,11 @@ void SemoduleDontaudit::processExited()
 void SemoduleDontaudit::semodule_dontaudit_base_process()
 {
 	this->setEnabled(false);
-	process = new Q3Process(this);
-	process->addArgument("/usr/share/segatex/DONTAUDIT_STATE");
+	process = new QProcess(this);
 	y = readFromOutputFile_and_return_str();
 	connect(process, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout()));
 	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
-	process->start();
+	process->start("/usr/share/segatex/DONTAUDIT_STATE");
 }
 
 int SemoduleDontaudit::readFromOutputFile_and_return_str()
@@ -145,7 +142,7 @@ int SemoduleDontaudit::readFromOutputFile_and_return_str()
 		file_interface_name = dir_name + forward_slash + name;
 		QFile file( file_interface_name );
 		if ( file.open( QIODevice::ReadOnly ) ) {
-			Q3TextStream stream( &file );
+			QTextStream stream( &file );
 			////////////////////////////////////////////
 			check_int = 0;
 			int lines = 1;
