@@ -21,25 +21,25 @@
 #ifndef USERADD_H
 #define USERADD_H
 
-#include <qregexp.h>
-#include <qdialog.h>
-#include <qradiobutton.h>
-#include <q3textedit.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <q3process.h>
-//Added by qt3to4:
+#include <QRegExp>
+#include <QDialog>
+#include <QRadioButton>
+#include <QTextEdit>
+#include <QLabel>
+#include <QLayout>
+#include <QCheckBox>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
+#include <QProcess>
+#include <QDir>
 //added in segatex7.8.10
 #include <unistd.h>
 
 
-class Q3TextEdit;
+class QTextEdit;
 class QLineEdit;
 class QPushButton;
-class Q3Process;
+class QProcess;
 
 class Useradd: public QDialog
 {
@@ -60,8 +60,8 @@ private slots:
 	void processExited();
 	void readFromOutputFile();
 private:
-	Q3Process *process;
-	Q3TextEdit *textEdit1;
+	QProcess *process;
+	QTextEdit *textEdit1;
 	QLabel *usernameLabel;
 	QLabel *passwordLabel;
 	QLabel *password2Label;
@@ -77,6 +77,8 @@ private:
 	QPushButton *readfromfileButton;
 	QPushButton *closeButton;
 	QString username_str;
+	QString username_str_ps1;
+	QString username_str_ps2;
 	QString passwordEditLineEdit_str;
 	QString password2EditLineEdit_str;
 
